==> 1.0.2.tar.gz: lib/api/dns_api.dart <==
part of forestvpn_api.api;



class DnsApi {
  final ApiClient apiClient;

  DnsApi([ApiClient apiClient]) : apiClient = apiClient ?? defaultApiClient;

  /// DNS Lookup
  ///
  /// 
  Future<Lookup> lookup({ LookupRequest request }) async {
    Object postBody = request;

    // verify required params are set

    // create path and map variables
    String path = "/dns/lookup".replaceAll("{format}","json");

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};
    
    List<String> contentTypes = ["application/json"];

    String contentType = contentTypes.length > 0 ? contentTypes[0] : "application/json";
    List<String> authNames = [];

    if(contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = new MultipartRequest(null, null);
      
      if(hasFields)
        postBody = mp;
    }
    else {
          }

    var response = await apiClient.invokeAPI(path,
                                             'POST',
                                             queryParams,
                                             postBody,
                                             headerParams,
                                             formParams,
                                             contentType,
                                             authNames);

    if(response.statusCode >= 400) {
      throw new ApiException(response.statusCode, response.body);
    } else if(response.body != null) {
      return 
          apiClient.deserialize(response.body, 'Lookup') as Lookup ;
    } else {
      return null;
    }
  }
}

==> 1.0.3.tar.gz: lib/api/dns_api.dart <==
part of forestvpn_api.api;



class DnsApi {
  final ApiClient apiClient;

  DnsApi([ApiClient apiClient]) : apiClient = apiClient ?? defaultApiClient;

  /// DNS Lookup with HTTP info returned
  ///
  /// 
  Future<Response> lookupWithHttpInfo({ LookupRequest request }) async {
    Object postBody = request;

    // verify required params are set

    // create path and map variables
    String path = "/dns/lookup".replaceAll("{format}","json");

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};

    List<String> contentTypes = ["application/json"];

    String contentType = contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = ["Bearer"];

    if(contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if(hasFields)
        postBody = mp;
    }
    else {
    }

    var response = await apiClient.invokeAPI(path,
                                             'POST',
                                             queryParams,
                                             postBody,
                                             headerParams,
                                             formParams,
                                             contentType,
                                             authNames);
    return response;
  }

  /// DNS Lookup
  ///
  /// 
  Future<Lookup> lookup({ LookupRequest request }) async {
    Response response = await lookupWithHttpInfo( request: request );
    if(response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if(response.body != null) {
      return apiClient.deserialize(_decodeBodyBytes(response), 'Lookup') as Lookup;
    } else {
      return null;
    }
  }

}
